@@ -56,7 +56,7 @@ def loadData(*dargs, **dkargs):
             if not os.path.exists(path):os.makedirs(path)
             if not os.path.exists(fileName) or isRealTime:
                 print(func.__name__ + f"\033[32m开始生成数据[{fileName}]\033[0m")
-                df =  func(*args, **kwargs)
+                df =  func(fileName = fileName,*args,**kwargs )
                 df.to_excel(fileName, sheet_name="数据源")
                 return df
             print(func.__name__ + f"读取数据[{fileName}]")
